<?php

	class IDEALCHECKOUT_FOR_DRUPAL_8_COMMERCE_2
	{
		// Return the software name
		public static function getSoftwareName()
		{
			return 'Drupal 8 - Commerce 2+';
		}



		// Return the software code
		public static function getSoftwareCode()
		{
			return str_replace('_', '-', substr(basename(__FILE__), 0, -4));
		}



		// Return path to main config file (if any)
		public static function getConfigFile()
		{
			return SOFTWARE_PATH . DS . 'sites' . DS . 'default' . DS . 'settings.php';
		}



		// Return path to main config file (if any)
		public static function getConfigData()
		{
			$sConfigFile = self::getConfigFile();

			// Detect DB settings via configuration file
			if(is_file($sConfigFile))
			{
				include($sConfigFile);

				if(sizeof($databases) && !empty($databases['default']['default']['host']))
				{
					return $databases['default']['default'];
				}

			}

			return '';
		}



		// Find default database settings
		public static function getDatabaseSettings($aSettings)
		{
			$aSettings['db_prefix'] = 'dc_';
			$aConfigData = self::getConfigData();

			if(!empty($aConfigData))
			{
				$aSettings['db_host'] = $aConfigData['host'];
				$aSettings['db_user'] = $aConfigData['username'];
				$aSettings['db_pass'] = $aConfigData['password'];
				$aSettings['db_name'] = $aConfigData['database'];
				$aSettings['db_prefix'] = $aConfigData['prefix'];
				// $aSettings['db_type'] = $aConfigData['driver'];

			}

			return $aSettings;
		}



		// See if current software == self::$sSoftwareCode
		public static function isSoftware()
		{
			$aFiles = array();
			$aFiles[] = SOFTWARE_PATH . DS . 'sites' . DS . 'default' . DS . 'settings.php';

			$aFiles[] = SOFTWARE_PATH . DS . 'modules' . DS . 'contrib' . DS . 'commerce' . DS . 'commerce.info.yml';

			foreach($aFiles as $sFile)
			{
				if(!is_file($sFile) && !is_dir($sFile))
				{
					return false;
				}
			}

			return true;
		}


		// Install plugin, return text
		public static function doInstall($aSettings)
		{
			IDEALCHECKOUT_INSTALL::doInstall($aSettings);

			$sql = "SHOW COLUMNS FROM `" . $aSettings['db_prefix'] . "idealcheckout_settings` LIKE `webshop_package`";

			if(!$aColumn = idealcheckout_database_getRecord($sql))
			{
				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "idealcheckout_settings` SET
`id` = NULL,
`keyname` = 'webshop_package',
`value` = 'drupal-8 commerce-2'";
				idealcheckout_database_execute($sql);

			}
			else
			{
				$sql = "UPDATE `" . $aSettings['db_prefix'] . "idealcheckout_settings` SET
`value` = 'drupal-8 commerce-2' WHERE (`keyname` = 'webshop_package') LIMIT 1";
				idealcheckout_database_execute($sql);
			}


			return true;
		}



		// Install plugin, return text
		public static function getInstructions($aSettings)
		{
			$sHtml = '';
			$sHtml .= '<ol>';
			$sHtml .= '<li>Log in op de beheeromgeving van uw webshop.</li>';
			$sHtml .= '<li>Ga naar Uitbreiding</li>';
			$sHtml .= '<li>Activeer de iDEAL Checkout uitbreiding.</li>';
			$sHtml .= '<li>Ga hierna naar Commerce -> Instellingen</li>';
			$sHtml .= '<li>Klik op de knop "Betaal gateways".</li>';
			$sHtml .= '<li>Klik op de knop "+Add payment gateway".</li>';
			$sHtml .= '<li>Vul bij het veld "Name/Naam" de waarde "iDEAL" in, Selecteer bij plugin iDEAL Checkout, Voer bij "Naam voor weergave" de naam die op de website zichtbaar moet zijn in.</li>';
			$sHtml .= '<li>Selecteer bij Betaalmethode "IDEAL".</li>';
			$sHtml .= '<li>Klik op opslaan</li>';
			$sHtml .= '<li>Herhaal stap 6 t/m 9 voor de overige betaalmethoden die u wilt aanbieden in uw webshop.</li>';
			$sHtml .= '</ol>';

			return $sHtml;
		}
	}

?>